@@ -3,13 +3,13 @@
 pub use miette_derive::*;
 
 pub use error::*;
+pub use printer::*;
 pub use protocol::*;
-pub use reporter::*;
 pub use utils::*;
 
 mod chain;
 mod error;
+mod printer;
 mod protocol;
-mod reporter;
 mod source_impls;
 mod utils;
